@@ -3,7 +3,7 @@ package Sah::Schema::date::month_nums;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 our $schema = ['array' => {
     summary => 'Array of month numbers',
@@ -11,12 +11,12 @@ our $schema = ['array' => {
     'x.perl.coerce_rules' => ['From_str::comma_sep'],
     'x.completion' => ['date_month_num'],
     examples => [
-        {value=>'', valid=>1},
+        {value=>'', valid=>1, validated_value=>[]},
         {value=>0, valid=>0},
-        {value=>1, valid=>1},
+        {value=>1, valid=>1, validated_value=>[1]},
         {value=>[1], valid=>1},
         {value=>[1,12], valid=>1},
-        {value=>'1,12', valid=>1},
+        {value=>'1,12', valid=>1, validated_value=>[1,12]},
         {value=>[1,12,13], valid=>0},
         {value=>'1,12,13', valid=>0},
     ],
@@ -38,7 +38,7 @@ Sah::Schema::date::month_nums - Array of month numbers
 
 =head1 VERSION
 
-This document describes version 0.011 of Sah::Schema::date::month_nums (from Perl distribution Sah-Schemas-Date), released on 2020-03-04.
+This document describes version 0.012 of Sah::Schema::date::month_nums (from Perl distribution Sah-Schemas-Date), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
