@@ -3,7 +3,7 @@ package Sah::Schema::date::tz_offset_lax;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Sah-Schemas-Date'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 our $schema = ['date::tz_offset' => {
     summary => 'Timezone offset in seconds from UTC',
@@ -28,17 +28,17 @@ A coercion from timezone name is also provided.
 _
     examples => [
         {value=>'', valid=>0},
-        {value=>'UTC', valid=>1, res=>0},
-        {value=>'3600', valid=>1, res=>3600},
-        {value=>'-43200', valid=>1, res=>-43200},
-        {value=>'-12', valid=>1, res=>-12*3600},
-        {value=>'-1200', valid=>1, res=>-12*3600},
-        {value=>'-12:00', valid=>1, res=>-12*3600},
-        {value=>'UTC-12', valid=>1, res=>-12*3600},
-        {value=>'UTC-1200', valid=>1, res=>-12*3600},
-        {value=>'UTC+12:45', valid=>1, res=>+12.75*3600},
+        {value=>'UTC', valid=>1, validated_value=>0},
+        {value=>'3600', valid=>1, validated_value=>3600},
+        {value=>'-43200', valid=>1, validated_value=>-43200},
+        {value=>'-12', valid=>1, validated_value=>-12*3600},
+        {value=>'-1200', valid=>1, validated_value=>-12*3600},
+        {value=>'-12:00', valid=>1, validated_value=>-12*3600},
+        {value=>'UTC-12', valid=>1, validated_value=>-12*3600},
+        {value=>'UTC-1200', valid=>1, validated_value=>-12*3600},
+        {value=>'UTC+12:45', valid=>1, validated_value=>+12.75*3600},
         {value=>'UTC-13', valid=>0},
-        {value=>'UTC+12:01', valid=>1, res=>+(12*3600+60)},
+        {value=>'UTC+12:01', valid=>1, validated_value=>+(12*3600+60)},
     ],
 }, {}];
 
@@ -58,7 +58,7 @@ Sah::Schema::date::tz_offset_lax - Timezone offset in seconds from UTC
 
 =head1 VERSION
 
-This document describes version 0.011 of Sah::Schema::date::tz_offset_lax (from Perl distribution Sah-Schemas-Date), released on 2020-03-04.
+This document describes version 0.012 of Sah::Schema::date::tz_offset_lax (from Perl distribution Sah-Schemas-Date), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
@@ -96,27 +96,27 @@ Sample data:
 
  undef  # INVALID
 
- undef  # valid, becomes 0
+ undef  # valid
 
- undef  # valid, becomes 3600
+ undef  # valid
 
- undef  # valid, becomes -43200
+ undef  # valid
 
- undef  # valid, becomes -43200
+ undef  # valid
 
- undef  # valid, becomes -43200
+ undef  # valid
 
- undef  # valid, becomes -43200
+ undef  # valid
 
- undef  # valid, becomes -43200
+ undef  # valid
 
- undef  # valid, becomes -43200
+ undef  # valid
 
- undef  # valid, becomes 45900
+ undef  # valid
 
  undef  # INVALID
 
- undef  # valid, becomes 43260
+ undef  # valid
 
 =head1 DESCRIPTION
 
